@@ -19,11 +19,16 @@ LOG = logging.getLogger(__name__)
 class Label(IWidget):
     """ Text Label with a fixed color and no state function.
     """
+    # Label alignment
+    LEFT = 0
+    CENTER = 1
+    RIGHT = 2
 
     def __init__(self, position, size,
                  font_size=None,
                  label=None,
                  label_color1=None,
+                 label_alignment=None,
                  **kwargs):
         """ Initialize the label with a subset of the Widget parameters.
 
@@ -41,8 +46,12 @@ class Label(IWidget):
         label : str
         label_color1 : Union[Tuple[int, int, int], Tuple[int, int, int, int]]
             Color of the Label
+        label_alignment : int
+            Alignment of the label in the box, one of LEFT, CENTER, or RIGHT
         """
         font_size = font_size or size[1]
+        self.alignment = label_alignment or Label.CENTER
+
         super(Label, self).__init__(position, size,
                                     font_size=font_size,
                                     label=label,
@@ -52,7 +61,12 @@ class Label(IWidget):
     def render(self, surface):
         color, label_color = self.state_colors()
 
-        self.render_centered_text(surface, self.label, label_color)
+        if self.alignment == Label.LEFT:
+            self.render_left_text(surface, self.label, label_color)
+        elif self.alignment == Label.CENTER:
+            self.render_centered_text(surface, self.label, label_color)
+        elif self.alignment == label.RIGHT:
+            self.render_right_text(surface, self.label, label_color)
 
     def can_focus(self):
         return False
